@@ -62,6 +62,7 @@ TargetsUi::TargetsUi(QObject *view, QWidget *parent)
     moveTargetDown->setToolTip(i18n("Move selected target down"));
 
     targetsView = new QTreeView(this);
+    targetsView->setFrameShape(QFrame::Shape::NoFrame);
     targetsView->setAlternatingRowColors(true);
 
     targetsView->setModel(&proxyModel);
@@ -72,9 +73,9 @@ TargetsUi::TargetsUi(QObject *view, QWidget *parent)
     targetsView->expandAll();
     targetsView->header()->setStretchLastSection(false);
     targetsView->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
-    targetsView->header()->setSectionResizeMode(1, QHeaderView::Stretch);
-    targetsView->header()->setSectionResizeMode(2, QHeaderView::Stretch);
-    QHBoxLayout *tLayout = new QHBoxLayout();
+    targetsView->header()->setSectionResizeMode(1, QHeaderView::Interactive);
+    targetsView->header()->setSectionResizeMode(2, QHeaderView::Interactive);
+    auto *tLayout = new QHBoxLayout();
 
     tLayout->addWidget(targetFilterEdit);
     tLayout->addWidget(buildButton);
@@ -87,9 +88,11 @@ TargetsUi::TargetsUi(QObject *view, QWidget *parent)
     tLayout->addWidget(moveTargetDown);
     tLayout->addWidget(deleteTarget);
     int leftMargin = QApplication::style()->pixelMetric(QStyle::PM_LayoutLeftMargin);
-    tLayout->setContentsMargins(leftMargin, 0, 0, 0);
+    int rightMargin = QApplication::style()->pixelMetric(QStyle::PM_LayoutRightMargin);
+    int topMargin = QApplication::style()->pixelMetric(QStyle::PM_LayoutTopMargin);
+    tLayout->setContentsMargins(leftMargin, topMargin, rightMargin, 0);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     layout->addLayout(tLayout);
     layout->addWidget(targetsView);
     layout->setContentsMargins(0, 0, 0, 0);
@@ -130,7 +133,7 @@ void TargetsUi::targetActivated(const QModelIndex &index)
     }
 }
 
-void TargetsUi::updateTargetsButtonStates()
+void TargetsUi::updateTargetsButtonStates() const
 {
     QModelIndex currentIndex = targetsView->currentIndex();
     if (!currentIndex.isValid()) {
@@ -187,26 +190,26 @@ void TargetsUi::pasteAfterCurrentItem()
 {
     const QModelIndex treeIndex = targetsView->currentIndex();
     const QModelIndex modelIndex = proxyModel.mapToSource(treeIndex);
-    targetsModel.insertAfter(modelIndex, QApplication::clipboard()->text());
+    targetsModel.insertAfter(modelIndex, QApplication::clipboard()->text(), currentProjectBaseDir);
 }
 
 void TargetsUi::customTargetsMenuRequested(const QPoint &pos)
 {
-    QTreeView *tree = qobject_cast<QTreeView *>(sender());
+    auto *tree = qobject_cast<QTreeView *>(sender());
     if (tree == nullptr) {
         return;
     }
-    QMenu *menu = new QMenu(tree);
+    auto *menu = new QMenu(tree);
 
-    QAction *copy = new QAction(i18n("Copy"), tree);
+    auto *copy = new QAction(i18n("Copy"), tree);
     menu->addAction(copy);
     copy->setShortcut(QKeySequence::Copy);
 
-    QAction *cut = new QAction(i18n("Cut"), tree);
+    auto *cut = new QAction(i18n("Cut"), tree);
     menu->addAction(cut);
     cut->setShortcut(QKeySequence::Cut);
 
-    QAction *paste = new QAction(i18n("Paste after"), tree);
+    auto *paste = new QAction(i18n("Paste after"), tree);
     menu->addAction(paste);
     paste->setShortcut(QKeySequence::Paste);
 
@@ -256,7 +259,10 @@ void TargetsUi::targetOrSetClone()
     QModelIndex currentIndex = targetsView->currentIndex();
     currentIndex = proxyModel.mapToSource(currentIndex);
     targetFilterEdit->setText(QString());
-    QModelIndex newIndex = targetsModel.cloneTargetOrSet(currentIndex);
+
+    QString json = targetsModel.indexToJson(currentIndex);
+
+    QModelIndex newIndex = targetsModel.insertAfter(currentIndex, json, currentProjectBaseDir);
     if (targetsModel.hasChildren(newIndex)) {
         newIndex = proxyModel.mapFromSource(newIndex);
         targetsView->setCurrentIndex(newIndex.model()->index(0, 0, newIndex));
@@ -279,21 +285,21 @@ void TargetsUi::targetDelete()
 
 bool TargetsUi::eventFilter(QObject *obj, QEvent *event)
 {
-    if (event->type() == QEvent::Show && obj == targetsView) {
-        QTimer::singleShot(100, this, [this]() {
-            targetsView->header()->setSectionResizeMode(1, QHeaderView::Interactive);
-            targetsView->header()->setSectionResizeMode(2, QHeaderView::Interactive);
-        });
+    if (event->type() == QEvent::Resize && obj == targetsView) {
+        QResizeEvent *e = static_cast<QResizeEvent *>(event);
+        double newSizeLeft = e->size().width() - targetsView->header()->sectionSize(0);
+        targetsView->header()->resizeSection(1, std::floor(columnCommandStretch * newSizeLeft));
+        targetsView->header()->resizeSection(2, std::floor((1.0 - columnCommandStretch) * newSizeLeft));
     }
     if (event->type() == QEvent::ShortcutOverride) {
         // Ignore copy in ShortcutOverride and handle it in the KeyPress event
-        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
+        auto *ke = static_cast<QKeyEvent *>(event);
         if (ke->matches(QKeySequence::Copy) || ke->matches(QKeySequence::Cut) || ke->matches(QKeySequence::Paste)) {
             event->accept();
             return true;
         }
     } else if (event->type() == QEvent::KeyPress) {
-        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        auto *keyEvent = static_cast<QKeyEvent *>(event);
         if (obj == targetsView) {
             if (keyEvent->matches(QKeySequence::Copy)) {
                 copyCurrentItem();
