@@ -9,9 +9,8 @@
 
 class BranchCheckoutDialog : public BranchesDialog
 {
-    Q_OBJECT
 public:
-    BranchCheckoutDialog(QWidget *mainWindow, QString projectPath);
+    BranchCheckoutDialog(QWidget *mainWindow, const QString &projectPath);
     ~BranchCheckoutDialog() override;
     void openDialog();
 
